#
# spec file for package lbzip2
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2021 Tristan Miller
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lbzip2
Version:        2.5
Release:        7.10
Summary:        Parallel bzip2/bunzip2 Filter
License:        GPL-3.0-or-later
Group:          Productivity/Archiving/Compression
URL:            https://github.com/kjn/lbzip2
Source:         lbzip2-%{version}.tar.bz2
BuildRequires:  libbz2-devel
Provides:       lbunzip2 = %{version}
Obsoletes:      lbunzip2 < %{version}

%description
Lbzip2 is a Pthreads-based parallel bzip2/bunzip2 filter, passable to
GNU tar with the --use-compress-program option.

It isn't restricted to regular files on input, nor output. Successful
splitting for decompression isn't guaranteed, just very likely
(failure is detected). Splitting in both modes and compression itself
occur with an approximate 900k block size.

On an Athlon-64 X2 6000+, lbzip2 was 92% faster than standard bzip2
when compressing, and 45% faster when decompressing (based on wall
clock time).

Lbzip2 strives to be portable by requiring UNIX 98 APIs only, besides
an unmodified libbz2.

%prep
%setup -q

%build
%configure
make %{?_smp_mflags}

%install
%make_install

%check
make %{?_smp_mflags} check

%files
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%{_bindir}/lbzip2
%{_bindir}/lbunzip2
%{_bindir}/lbzcat
%{_mandir}/man1/lbzip2.1%{?ext_man}
%{_mandir}/man1/lbunzip2.1%{?ext_man}
%{_mandir}/man1/lbzcat.1%{?ext_man}

%changelog
* Wed Apr 28 2021 psychonaut@nothingisreal.com
- Update project URL in spec file; the previously official domain
  lbzip2.org has seemingly lapsed and been taken over by an impostor
* Sat Jun 15 2019 psychonaut@nothingisreal.com
- Replace source tarball with one using the latest version of gnulib;
  this works around the build failure caused by incompatible updates
  to glibc 2.28.  For further details see
  <https://github.com/kjn/lbzip2/issues/22> and
  <https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=915171>. Note
  that it was not possible to (cleanly) provide a patchfile due to the
  peculiar way in which the lbzip2 source distribution is
  bootstrapped; the bootstrap script pulls in the gnulib source, runs
  some code generation scripts, and then calls the Autotools toolchain
  on the result.  Since the Autotools input and output files end up
  getting modified by the patch, the build process fails because it
  thinks the generated versions are out of date.
* Wed Mar 14 2018 mpluskal@suse.com
- Modernise spec file with spec-cleaner
* Sun Apr 12 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Cleanup dependencies
* Thu Apr 10 2014 idonmez@suse.com
- Update to version 2.5
  * Performance improvements.
  * Fixed a decompression bug in bz2 header parsing code.
  * Fixed an assertion failure bug that could cause core dumps when
    compressing some kind of data.
  * Fixed a bug which prevented symbolic links to be opened in some
    situations.
  * Fixed a bug that caused SIGXFSZ to be handled incorrectly on 32-bit
    systems.
* Mon Aug 20 2012 pascal.bleser@opensuse.org
- update to 2.2:
  * decompressor was made more bzip2-compatible: all valid bzip2 files should
    now be properly decompressed by lbzip2
  * memory allocation was reduced significantly: previous versions could
    allocate large amounts of memory during decompression and testing of highly
    compressed files
  * fixes a bug that caused some legitimate bz2 files to be rejected during
    decompression with a CRC error message
  * compression performance is increased significantly by inclusion of new
    block-sorting code using divsufsort algorithm
  * file write errors caused by broken pipes or exceeded file size limits are
    no longer reported to standard error
* Thu Nov 24 2011 pascal.bleser@opensuse.org
- license changes from GPL v2+ to GPL v3.0
- update to 2.1:
  * fixes a use-after-free security vulnerability in decompressor code
    responsible for displaying progress information
- changes from 2.0:
  * now lbzip2 creates one compressed stream per bzip2 file instead of multiple
    concatenated streams
  * lbzip2 now doesn't decompress streams embedded within trailing garbage
    after initial sequence of streams
  * now lbzip2 detects and rejects more kinds of invalid bzip2 files (files
    with invalid stream CRCs, files with blocks larger than stated in stream
    headers and some others)
  * both compression and decompression speed is increased significantly
  * when invoked with `-v' or `--verbose' options lbzip2 now displays
    information about progress of compression or decompression, provided that
    stderr is connected to a terminal
  * when invoked with `-v' or `--verbose' options lbzip2 now displays
    compression ratio and space savings for each compressed or decompressed
    file
  * lbzip2 now supports `--exponential' option with the same semantics as
    bzip2's one
  * now lbzip2 displays more detailed messages on decompression failure
  * help and version information is now printed to standard output instead of
    standard error stream
  * abandoned support for tracing memory allocation by setting the
    environmental variable `LBZIP2_TRACE_ALLOC', was dropped
* Wed Mar  3 2010 pascal.bleser@opensuse.org
- update to 0.23:
  * if lbzip2 intends to exit with status 1 due to any fatal error,
    but any SIGPIPE or SIGXFSZ with an inherited SIG_DFL action was
    generated for lbzip2 previously, then lbzip2 terminates by way
    of one of the said signals, after cleaning up any interrupted
    output file; this should improve compatibility with GNU tar
    when it spawns lbzip2 as a filter and closes the pipe between
    them early, before it receives an EOF from lbzip2
* Thu Feb 18 2010 pascal.bleser@opensuse.org
- update to 0.21:
  * fixes a race condition
* Mon Dec 28 2009 pascal.bleser@opensuse.org
- update to 0.20:
  * portability fixes
* Sun Nov 29 2009 pascal.bleser@opensuse.org
- update to 0.18:
  * sanity checks were added to both decompressors
  * input FILE operands were removed
  * the --keep and --force options were added
  * owner, group, permission bits, access time, modification time
    are copied to regular output files
  * logging was cleaned up and internally categorized into INFO,
    WARNING, and FATAL levels
  * a separate exit status was introduced for the case when a
    warning message was printed
  * the decompressor robustness tests were re-executed
* Wed Oct 28 2009 pascal.bleser@opensuse.org
- update to 0.17:
  * uninitialized fields were accessed on the stack in a structure assignment expression
* Sun Oct 25 2009 pascal.bleser@opensuse.org
- update to 0.16:
  * configurable compression block size
  * file operands
* Sun Apr  5 2009 pascal.bleser@opensuse.org
- update to 0.15:
  * a bug has been fixed where the single-worker decompressor could
    theoretically skip decompression of the last part of the compressed input
    and incorrectly signify premature EOF instead
  * logically independent buffer sizes are detached from each other
  * several buffer sizes should be more I/O-friendly now
  * the splitter block size of the multiple-workers decompressor was
    recalculated; an effort was made to deduce it formally in comments
  * the "malloc_trace.pl" script tracks peak memory usage
  * the documentation was refined
* Sat Mar 21 2009 pascal.bleser@opensuse.org
- better upstream URL, voids the necessity of source checks
* Thu Mar 19 2009 pascal.bleser@opensuse.org
- added Obsoletes: for lbunzip2, as this package replaces it
* Sun Mar 15 2009 pascal.bleser@opensuse.org
- new package
